ConfigCommands

Enum ConfigCommands 

enum ConfigCommands {
    Get(ConfigGetArgs),
    Update(ConfigUpdateArgs),
}

Variants



Get(ConfigGetArgs)

Retrieves the current config used by the server - the default command.



Update(ConfigUpdateArgs)

Temporarily updates part of the server configuration.

The changes are made in-memory, not on disk, and thus only persist across ‘soft’ server restarts (where the pubhubs serve process does not actually restart) such as the ones caused by discovery.

Implementations